@@ -1,6 +1,7 @@
 import os
 import textwrap
 from abc import ABC
+from copy import deepcopy
 from logging import debug
 from pathlib import Path
 from types import SimpleNamespace
@@ -12,6 +13,7 @@ from yamlpath.common import Parsers
 from yamlpath.wrappers import ConsolePrinter
 
 from gitlabform import EXIT_INVALID_INPUT
+from ruamel.yaml.comments import CommentedMap
 
 
 class ConfigurationCore(ABC):
@@ -42,12 +44,12 @@ class ConfigurationCore(ABC):
                         exit_code=EXIT_INVALID_INPUT,
                     )
 
-                if self.config.get("config_version", 1) != 2:
+                if self.config.get("config_version", 1) != 3:
                     fatal(
-                        "This version of GitLabForm requires 'config_version: 2' entry in the config.\n"
-                        "This ensures that when the application behavior changes in a backward incompatible way,"
-                        " you won't apply unexpected configuration to your GitLab instance.\n"
-                        "Please read the upgrading guide here: https://bit.ly/3ub1g5C\n",
+                        "This version of GitLabForm requires 'config_version: 3' entry in the config. "
+                        "This ensures that if the application behavior changes in a backward-incompatible way,"
+                        " you won't apply unwanted configuration to your GitLab instance.\n"
+                        "Please follow this guide: https://gitlabform.github.io/gitlabform/upgrade/\n",
                         exit_code=EXIT_INVALID_INPUT,
                     )
 
@@ -151,7 +153,11 @@ class ConfigurationCore(ABC):
         """
         :return: literal common configuration or empty dict if not defined
         """
-        return self.get("projects_and_groups|*", {})
+        common_config = self.get("projects_and_groups|*", {})
+        if common_config:
+            section_name = "*"
+            self.validate_break_inheritance_flag(common_config, section_name)
+        return common_config
 
     def is_project_skipped(self, project) -> bool:
         pass
@@ -162,13 +168,63 @@ class ConfigurationCore(ABC):
     def is_skipped(self, an_array: list, item: str) -> bool:
         pass
 
+    @staticmethod
+    def validate_break_inheritance_flag(config, section_name, parent_key=""):
+        for key, value in config.items():
+            if "inherit" == key:
+                parent_key_description = (
+                    ' under key "' + parent_key + '"' if parent_key else ""
+                )
+                fatal(
+                    f'The inheritance-break flag set in "{section_name}"{parent_key_description} is invalid\n'
+                    f"because it has no higher level setting to inherit from.\n",
+                    exit_code=EXIT_INVALID_INPUT,
+                )
+            elif type(value) is CommentedMap:
+                ConfigurationCore.validate_break_inheritance_flag(
+                    value, section_name, key
+                )
+
     @staticmethod
     def merge_configs(more_general_config, more_specific_config) -> dict:
         """
         :return: merge more general config with more specific configs.
                  More specific config values take precedence over more general ones.
         """
-        return dict(merge({}, more_general_config, more_specific_config))
+
+        more_general_config = deepcopy(more_general_config)
+        more_specific_config = deepcopy(more_specific_config)
+
+        merged_dict = merge({}, more_general_config, more_specific_config)
+
+        def break_inheritance(specific_config, parent_key=""):
+            for key, value in specific_config.items():
+                if "inherit" == key:
+                    if not value:
+                        replace_config_sections(
+                            merged_dict, parent_key, specific_config
+                        )
+                        break
+                    elif value:
+                        fatal(
+                            f"Cannot set the inheritance break flag with true\n",
+                            exit_code=EXIT_INVALID_INPUT,
+                        )
+                elif type(value) is CommentedMap:
+                    break_inheritance(value, key)
+
+        def replace_config_sections(merged_config, specific_key, specific_config):
+            for key, value in merged_config.items():
+                if specific_key == key:
+                    del specific_config["inherit"]
+                    merged_config[key] = specific_config
+                    break
+                elif type(value) is CommentedMap:
+                    replace_config_sections(value, specific_key, specific_config)
+
+        break_inheritance(more_specific_config)
+
+        return dict(merged_dict)
 
 
 class ConfigFileNotFoundException(Exception):
