@@ -6,13 +6,16 @@ from gitlabform.gitlab.branches import GitLabBranches
 from gitlabform.gitlab.commits import GitLabCommits
 from gitlabform.gitlab.group_badges import GitLabGroupBadges
 from gitlabform.gitlab.group_ldap_links import GitLabGroupLDAPLinks
+from gitlabform.gitlab.group_variables import GitLabGroupVariables
 from gitlabform.gitlab.members import GitLabMembers
 from gitlabform.gitlab.merge_requests import GitLabMergeRequests
 from gitlabform.gitlab.pipelines import GitLabPipelines
 from gitlabform.gitlab.project_badges import GitLabProjectBadges
+from gitlabform.gitlab.project_deploy_keys import GitLabProjectDeployKeys
+from gitlabform.gitlab.variables import GitLabVariables
 from gitlabform.gitlab.repositories import GitLabRepositories
 from gitlabform.gitlab.schedules import GitLabPipelineSchedules
-from gitlabform.gitlab.services import GitLabServices
+from gitlabform.gitlab.integrations import GitLabIntegrations
 from gitlabform.gitlab.tags import GitLabTags
 from gitlabform.gitlab.users import GitLabUsers
 
@@ -47,14 +50,17 @@ class GitLab(
     GitLabCommits,
     GitLabMergeRequests,
     GitLabRepositories,
-    GitLabServices,
+    GitLabIntegrations,
     GitLabTags,
     GitLabGroupLDAPLinks,
     GitLabGroupBadges,
+    GitLabGroupVariables,
     GitLabPipelines,
     GitLabMembers,
     GitLabUsers,
     GitLabPipelineSchedules,
     GitLabProjectBadges,
+    GitLabProjectDeployKeys,
+    GitLabVariables,
 ):
     pass
